# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from sdk.gen.storage.v2 import storage_pb2 as storage_dot_v2_dot_storage__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in storage/v2/storage_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class StorageStub(object):
    """Services for storage and retrieval of blobs in the form of byte arrays, such as text and binary blobs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Read = channel.unary_unary(
                '/nitric.proto.storage.v2.Storage/Read',
                request_serializer=storage_dot_v2_dot_storage__pb2.StorageReadRequest.SerializeToString,
                response_deserializer=storage_dot_v2_dot_storage__pb2.StorageReadResponse.FromString,
                _registered_method=True)
        self.Write = channel.unary_unary(
                '/nitric.proto.storage.v2.Storage/Write',
                request_serializer=storage_dot_v2_dot_storage__pb2.StorageWriteRequest.SerializeToString,
                response_deserializer=storage_dot_v2_dot_storage__pb2.StorageWriteResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/nitric.proto.storage.v2.Storage/Delete',
                request_serializer=storage_dot_v2_dot_storage__pb2.StorageDeleteRequest.SerializeToString,
                response_deserializer=storage_dot_v2_dot_storage__pb2.StorageDeleteResponse.FromString,
                _registered_method=True)
        self.PreSignUrl = channel.unary_unary(
                '/nitric.proto.storage.v2.Storage/PreSignUrl',
                request_serializer=storage_dot_v2_dot_storage__pb2.StoragePreSignUrlRequest.SerializeToString,
                response_deserializer=storage_dot_v2_dot_storage__pb2.StoragePreSignUrlResponse.FromString,
                _registered_method=True)
        self.ListBlobs = channel.unary_unary(
                '/nitric.proto.storage.v2.Storage/ListBlobs',
                request_serializer=storage_dot_v2_dot_storage__pb2.StorageListBlobsRequest.SerializeToString,
                response_deserializer=storage_dot_v2_dot_storage__pb2.StorageListBlobsResponse.FromString,
                _registered_method=True)
        self.Exists = channel.unary_unary(
                '/nitric.proto.storage.v2.Storage/Exists',
                request_serializer=storage_dot_v2_dot_storage__pb2.StorageExistsRequest.SerializeToString,
                response_deserializer=storage_dot_v2_dot_storage__pb2.StorageExistsResponse.FromString,
                _registered_method=True)


class StorageServicer(object):
    """Services for storage and retrieval of blobs in the form of byte arrays, such as text and binary blobs.
    """

    def Read(self, request, context):
        """Retrieve an item from a bucket
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Write(self, request, context):
        """Store an item to a bucket
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete an item from a bucket
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreSignUrl(self, request, context):
        """Generate a pre-signed URL for direct operations on an item
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBlobs(self, request, context):
        """List blobs currently in the bucket
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exists(self, request, context):
        """Determine is an object exists in a bucket
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StorageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Read': grpc.unary_unary_rpc_method_handler(
                    servicer.Read,
                    request_deserializer=storage_dot_v2_dot_storage__pb2.StorageReadRequest.FromString,
                    response_serializer=storage_dot_v2_dot_storage__pb2.StorageReadResponse.SerializeToString,
            ),
            'Write': grpc.unary_unary_rpc_method_handler(
                    servicer.Write,
                    request_deserializer=storage_dot_v2_dot_storage__pb2.StorageWriteRequest.FromString,
                    response_serializer=storage_dot_v2_dot_storage__pb2.StorageWriteResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=storage_dot_v2_dot_storage__pb2.StorageDeleteRequest.FromString,
                    response_serializer=storage_dot_v2_dot_storage__pb2.StorageDeleteResponse.SerializeToString,
            ),
            'PreSignUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.PreSignUrl,
                    request_deserializer=storage_dot_v2_dot_storage__pb2.StoragePreSignUrlRequest.FromString,
                    response_serializer=storage_dot_v2_dot_storage__pb2.StoragePreSignUrlResponse.SerializeToString,
            ),
            'ListBlobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBlobs,
                    request_deserializer=storage_dot_v2_dot_storage__pb2.StorageListBlobsRequest.FromString,
                    response_serializer=storage_dot_v2_dot_storage__pb2.StorageListBlobsResponse.SerializeToString,
            ),
            'Exists': grpc.unary_unary_rpc_method_handler(
                    servicer.Exists,
                    request_deserializer=storage_dot_v2_dot_storage__pb2.StorageExistsRequest.FromString,
                    response_serializer=storage_dot_v2_dot_storage__pb2.StorageExistsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nitric.proto.storage.v2.Storage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('nitric.proto.storage.v2.Storage', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Storage(object):
    """Services for storage and retrieval of blobs in the form of byte arrays, such as text and binary blobs.
    """

    @staticmethod
    def Read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.storage.v2.Storage/Read',
            storage_dot_v2_dot_storage__pb2.StorageReadRequest.SerializeToString,
            storage_dot_v2_dot_storage__pb2.StorageReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Write(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.storage.v2.Storage/Write',
            storage_dot_v2_dot_storage__pb2.StorageWriteRequest.SerializeToString,
            storage_dot_v2_dot_storage__pb2.StorageWriteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.storage.v2.Storage/Delete',
            storage_dot_v2_dot_storage__pb2.StorageDeleteRequest.SerializeToString,
            storage_dot_v2_dot_storage__pb2.StorageDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreSignUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.storage.v2.Storage/PreSignUrl',
            storage_dot_v2_dot_storage__pb2.StoragePreSignUrlRequest.SerializeToString,
            storage_dot_v2_dot_storage__pb2.StoragePreSignUrlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListBlobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.storage.v2.Storage/ListBlobs',
            storage_dot_v2_dot_storage__pb2.StorageListBlobsRequest.SerializeToString,
            storage_dot_v2_dot_storage__pb2.StorageListBlobsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Exists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.storage.v2.Storage/Exists',
            storage_dot_v2_dot_storage__pb2.StorageExistsRequest.SerializeToString,
            storage_dot_v2_dot_storage__pb2.StorageExistsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from pubsub.v2 import pubsub_pb2 as pubsub_dot_v2_dot_pubsub__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in pubsub/v2/pubsub_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PubsubStub(object):
    """Service for publishing asynchronous messages
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Publish = channel.unary_unary(
                '/nitric.proto.pubsub.v1.Pubsub/Publish',
                request_serializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishRequest.SerializeToString,
                response_deserializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishResponse.FromString,
                _registered_method=True)


class PubsubServicer(object):
    """Service for publishing asynchronous messages
    """

    def Publish(self, request, context):
        """Publishes a message to a given topic
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PubsubServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Publish': grpc.unary_unary_rpc_method_handler(
                    servicer.Publish,
                    request_deserializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishRequest.FromString,
                    response_serializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nitric.proto.pubsub.v1.Pubsub', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('nitric.proto.pubsub.v1.Pubsub', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Pubsub(object):
    """Service for publishing asynchronous messages
    """

    @staticmethod
    def Publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.pubsub.v1.Pubsub/Publish',
            pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishRequest.SerializeToString,
            pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pubsub/v2/pubsub.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'pubsub/v2/pubsub.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16pubsub/v2/pubsub.proto\x12\x16nitric.proto.pubsub.v1\"8\n\x14PubsubPublishRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x17\n\x15PubsubPublishResponse2p\n\x06Pubsub\x12\x66\n\x07Publish\x12,.nitric.proto.pubsub.v1.PubsubPublishRequest\x1a-.nitric.proto.pubsub.v1.PubsubPublishResponseB\x9b\x01\n\x19io.nitric.proto.pubsub.v2B\x13PubsubPubsubServiceP\x01Z5github.com/nitrictech/nitric/proto/pubsub/v2;pubsubpb\xaa\x02\x16Nitric.Proto.Pubsub.v2\xca\x02\x16Nitric\\Proto\\Pubsub\\V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pubsub.v2.pubsub_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031io.nitric.proto.pubsub.v2B\023PubsubPubsubServiceP\001Z5github.com/nitrictech/nitric/proto/pubsub/v2;pubsubpb\252\002\026Nitric.Proto.Pubsub.v2\312\002\026Nitric\\Proto\\Pubsub\\V2'
  _globals['_PUBSUBPUBLISHREQUEST']._serialized_start=50
  _globals['_PUBSUBPUBLISHREQUEST']._serialized_end=106
  _globals['_PUBSUBPUBLISHRESPONSE']._serialized_start=108
  _globals['_PUBSUBPUBLISHRESPONSE']._serialized_end=131
  _globals['_PUBSUB']._serialized_start=133
  _globals['_PUBSUB']._serialized_end=245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: storage/v2/storage.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'storage/v2/storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18storage/v2/storage.proto\x12\x17nitric.proto.storage.v2\x1a\x1egoogle/protobuf/duration.proto\"E\n\x13StorageWriteRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\x0c\"\x16\n\x14StorageWriteResponse\"6\n\x12StorageReadRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"#\n\x13StorageReadResponse\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\"8\n\x14StorageDeleteRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x17\n\x15StorageDeleteResponse\"\xd9\x01\n\x18StoragePreSignUrlRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12N\n\toperation\x18\x03 \x01(\x0e\x32;.nitric.proto.storage.v2.StoragePreSignUrlRequest.Operation\x12)\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\" \n\tOperation\x12\x08\n\x04READ\x10\x00\x12\t\n\x05WRITE\x10\x01\"(\n\x19StoragePreSignUrlResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\">\n\x17StorageListBlobsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\"\x13\n\x04\x42lob\x12\x0b\n\x03key\x18\x01 \x01(\t\"H\n\x18StorageListBlobsResponse\x12,\n\x05\x62lobs\x18\x01 \x03(\x0b\x32\x1d.nitric.proto.storage.v2.Blob\"8\n\x14StorageExistsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\'\n\x15StorageExistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x32\x8b\x05\n\x07Storage\x12\x61\n\x04Read\x12+.nitric.proto.storage.v2.StorageReadRequest\x1a,.nitric.proto.storage.v2.StorageReadResponse\x12\x64\n\x05Write\x12,.nitric.proto.storage.v2.StorageWriteRequest\x1a-.nitric.proto.storage.v2.StorageWriteResponse\x12g\n\x06\x44\x65lete\x12-.nitric.proto.storage.v2.StorageDeleteRequest\x1a..nitric.proto.storage.v2.StorageDeleteResponse\x12s\n\nPreSignUrl\x12\x31.nitric.proto.storage.v2.StoragePreSignUrlRequest\x1a\x32.nitric.proto.storage.v2.StoragePreSignUrlResponse\x12p\n\tListBlobs\x12\x30.nitric.proto.storage.v2.StorageListBlobsRequest\x1a\x31.nitric.proto.storage.v2.StorageListBlobsResponse\x12g\n\x06\x45xists\x12-.nitric.proto.storage.v2.StorageExistsRequest\x1a..nitric.proto.storage.v2.StorageExistsResponseB\x9b\x01\n\x1aio.nitric.proto.storage.v2B\x0eStorageServiceP\x01Z7github.com/nitrictech/nitric/proto/storage/v2;storagepb\xaa\x02\x17Nitric.Proto.Storage.v2\xca\x02\x17Nitric\\Proto\\Storage\\V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'storage.v2.storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.nitric.proto.storage.v2B\016StorageServiceP\001Z7github.com/nitrictech/nitric/proto/storage/v2;storagepb\252\002\027Nitric.Proto.Storage.v2\312\002\027Nitric\\Proto\\Storage\\V2'
  _globals['_STORAGEWRITEREQUEST']._serialized_start=85
  _globals['_STORAGEWRITEREQUEST']._serialized_end=154
  _globals['_STORAGEWRITERESPONSE']._serialized_start=156
  _globals['_STORAGEWRITERESPONSE']._serialized_end=178
  _globals['_STORAGEREADREQUEST']._serialized_start=180
  _globals['_STORAGEREADREQUEST']._serialized_end=234
  _globals['_STORAGEREADRESPONSE']._serialized_start=236
  _globals['_STORAGEREADRESPONSE']._serialized_end=271
  _globals['_STORAGEDELETEREQUEST']._serialized_start=273
  _globals['_STORAGEDELETEREQUEST']._serialized_end=329
  _globals['_STORAGEDELETERESPONSE']._serialized_start=331
  _globals['_STORAGEDELETERESPONSE']._serialized_end=354
  _globals['_STORAGEPRESIGNURLREQUEST']._serialized_start=357
  _globals['_STORAGEPRESIGNURLREQUEST']._serialized_end=574
  _globals['_STORAGEPRESIGNURLREQUEST_OPERATION']._serialized_start=542
  _globals['_STORAGEPRESIGNURLREQUEST_OPERATION']._serialized_end=574
  _globals['_STORAGEPRESIGNURLRESPONSE']._serialized_start=576
  _globals['_STORAGEPRESIGNURLRESPONSE']._serialized_end=616
  _globals['_STORAGELISTBLOBSREQUEST']._serialized_start=618
  _globals['_STORAGELISTBLOBSREQUEST']._serialized_end=680
  _globals['_BLOB']._serialized_start=682
  _globals['_BLOB']._serialized_end=701
  _globals['_STORAGELISTBLOBSRESPONSE']._serialized_start=703
  _globals['_STORAGELISTBLOBSRESPONSE']._serialized_end=775
  _globals['_STORAGEEXISTSREQUEST']._serialized_start=777
  _globals['_STORAGEEXISTSREQUEST']._serialized_end=833
  _globals['_STORAGEEXISTSRESPONSE']._serialized_start=835
  _globals['_STORAGEEXISTSRESPONSE']._serialized_end=874
  _globals['_STORAGE']._serialized_start=877
  _globals['_STORAGE']._serialized_end=1528
# @@protoc_insertion_point(module_scope)



from typing import Optional, List
from sdk.gen.storage.v2 import storage_pb2, storage_pb2_grpc
from google.protobuf.duration_pb2 import Duration


class Mode:
    READ = "READ"
    WRITE = "WRITE"


class PresignUrlOptions:
    def __init__(self, mode: str = Mode.READ, expiry: int = 300):
        self.mode = mode
        self.expiry = expiry


class Bucket:
    def __init__(self, storage_client: storage_pb2_grpc.StorageStub, bucket_name: str):
        self.name = bucket_name
        self.storage_client = storage_client

    async def read(self, key: str) -> bytes:
        request = storage_pb2.StorageReadRequest(bucket_name=self.name, key=key)
        response = await self.storage_client.Read(request)
        return response.body

    async def write(self, key: str, data: bytes) -> None:
        request = storage_pb2.StorageWriteRequest(
            bucket_name=self.name,
            key=key,
            body=data,
        )
        await self.storage_client.Write(request)

    async def delete(self, key: str) -> None:
        request = storage_pb2.StorageDeleteRequest(bucket_name=self.name, key=key)
        await self.storage_client.Delete(request)

    async def list(self, prefix: str = "") -> List[str]:
        request = storage_pb2.StorageListBlobsRequest(bucket_name=self.name, prefix=prefix)
        response = await self.storage_client.ListBlobs(request)
        return [blob.key for blob in response.blobs]

    async def exists(self, key: str) -> bool:
        request = storage_pb2.StorageExistsRequest(bucket_name=self.name, key=key)
        response = await self.storage_client.Exists(request)
        return response.exists

    async def get_download_url(self, key: str, options: Optional[PresignUrlOptions] = None) -> str:
        opts = options or PresignUrlOptions(mode=Mode.READ, expiry=300)
        return await self._pre_sign_url(key, opts)

    async def get_upload_url(self, key: str, options: Optional[PresignUrlOptions] = None) -> str:
        opts = options or PresignUrlOptions(mode=Mode.WRITE, expiry=300)
        return await self._pre_sign_url(key, opts)

    async def _pre_sign_url(self, key: str, options: PresignUrlOptions) -> str:
        operation = (
            storage_pb2.StoragePreSignUrlRequest.READ
            if options.mode == Mode.READ
            else storage_pb2.StoragePreSignUrlRequest.WRITE
        )

        request = storage_pb2.StoragePreSignUrlRequest(
            bucket_name=self.name,
            key=key,
            operation=operation,
            expiry=Duration(seconds=options.expiry),
        )

        response = await self.storage_client.PreSignUrl(request)
        return response.url
